from setuptools import setup, find_packages

setup(
    name="cursor-agent",
    version="0.1.4",
    packages=find_packages(include=['cursor_agent', 'cursor_agent.*', 'cursor_agent.tools.*']),
    include_package_data=True,
    package_data={
        'cursor_agent': [
            '.cursorrules',
            '.env.example',
            'requirements.txt',
        ],
    },
    install_requires=[
        'requests>=2.31.0',
        'playwright>=1.40.0',
        'anthropic>=0.7.0',
        'openai>=1.3.0',
        'google-generativeai>=0.3.0',
        'python-dotenv>=1.0.0',
        'duckduckgo-search>=4.1.1',
        'html5lib>=1.1',
        'packaging>=23.2',
    ],
    entry_points={
        'console_scripts': [
            'cursor-agent=cursor_agent.main:main',
            'cursor-scrape=cursor_agent.tools.web_scraper:main',
            'cursor-search=cursor_agent.tools.search_engine:main',
            'cursor-llm=cursor_agent.tools.llm_api:main',
            'cursor-update=cursor_agent.tools.update_cursor_agent:main',
            'cursor-verify=cursor_agent.tools.verify_setup:main',
            'cursor-changelog=cursor_agent.tools.generate_changelog:main',
        ],
    },
    python_requires='>=3.8',
    author="grapeot",
    author_email="",
    description="A tool for initializing projects with Cursor agent capabilities",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/grapeot/devin.cursorrules",
    project_urls={
        "Bug Tracker": "https://github.com/grapeot/devin.cursorrules/issues",
        "Documentation": "https://github.com/grapeot/devin.cursorrules#readme",
        "Source Code": "https://github.com/grapeot/devin.cursorrules",
    },
    keywords="cursor, agent, llm, ai, automation, development",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Software Development :: Testing",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Natural Language :: English",
        "Environment :: Console",
    ],
) 